mgp2pdf TODO
------------

- [x] Package and upload to PyPI
- [x] Add a test suite and set up Travis & Jenkins
- [ ] Set up test coverage measurement
- [ ] Add some sensible integration tests
- [ ] Python 3 support
- [ ] Handle tabs at the beginning of line (i.e. bullet points; see lecture5.mgp)
- [ ] Cmdline option to enable unsafe directives (%filter)
- [ ] Trap MgpSyntaxErrors, print filename and line number

Maybe
-----

- [ ] Compare output with mgp's output semiautomatically (screenshot, diff pixmaps)
- [ ] Config file for font mappings (xfont "andale mono" -> /path/to/file.ttf)
- [ ] --title, --author, --subject cmdline options
- [ ] PDF outlines
